#version 460 compatibility

//Diffuse (color) texture.
uniform sampler2D texture;
//Lighting from day/night + shadows + light sources.
uniform sampler2D lightmap;

//RGB/intensity for hurt entities and flashing creepers.
uniform vec4 entityColor;

//Fog mode
uniform int fogMode;
const int GL_LINEAR = 9729;
const int GL_EXP = 2048;

//0 = default, 1 = water, 2 = lava.
uniform int isEyeInWater;

//Vertex color.
varying vec4 color;
//Diffuse and lightmap texture coordinates.
varying vec2 coord0;
varying vec2 coord1;

varying float dist;

varying vec3 world_position;

void main()
{
    vec4 albedo = (color * texture2D(texture,coord0) * texture2D(lightmap,coord1));

    float fog;
    if(fogMode == GL_LINEAR){
        fog = clamp((gl_FogFragCoord-gl_Fog.start) * gl_Fog.scale, 0., 1.);		
    } else if(fogMode == GL_EXP || isEyeInWater >= 1){
        fog = 1.-clamp(exp(-gl_FogFragCoord * gl_Fog.density), 0., 1.);
    }

    albedo.rgb = mix(albedo.rgb, gl_Fog.color.rgb, fog);

    albedo *= 16;
    albedo = round(albedo);
    albedo /= 16;

    gl_FragData[0] = albedo;
}
